summaryrefslogtreecommitdiff
path: root/common.nix
diff options
context:
space:
mode:
Diffstat (limited to 'common.nix')
-rw-r--r--common.nix16
1 files changed, 7 insertions, 9 deletions
diff --git a/common.nix b/common.nix
index 98c2200..a64a3a3 100644
--- a/common.nix
+++ b/common.nix
@@ -56,23 +56,21 @@ in
options = [ "defaults" "size=8G" "mode=755" ];
};
# nix store file system from encrypted disk
fileSystems."/nix" =
- { device = "/dev/mapper/crypt-system";
- fsType = "btrfs";
+ { device = "zpool/nix";
+ fsType = "zfs";
neededForBoot = true;
- options = [ "subvol=nix" "noatime" "nodiratime" ];
};
# data store file system from encrypted disk
fileSystems."/data" =
- { device = "/dev/mapper/crypt-system";
- fsType = "btrfs";
+ { device = "zpool/data";
+ fsType = "zfs";
neededForBoot = true;
- options = [ "subvol=data" "noatime" "nodiratime" ];
};
- # bind mount to have homes
+ # bind mount to have user homes
fileSystems."/home" =
{ device = "/data/home";
fsType = "none";
@@ -56,23 +56,21 @@ in
options = [ "defaults" "size=8G" "mode=755" ];
};
- # nix store file system from encrypted disk
+ # nix store file system from encrypted ZFS
fileSystems."/nix" =
@@ -56,23 +56,21 @@ in
};
- # data store file system from encrypted disk
+ # data store file system from encrypted ZFS
fileSystems."/data" =